# BDQuaternions

![Build](https://github.com/bond-anton/BDQuaternions/workflows/Build/badge.svg)
[![codecov](https://codecov.io/gh/bond-anton/BDQuaternions/branch/master/graph/badge.svg)](https://codecov.io/gh/bond-anton/BDQuaternions)

**BDQuaternions** is a python package for manipulation with quaternions objects.
It is tested to be compatible with python 3.4.

Available classes are
* Quaternion
* UnitQuaternion
* Rotation
* EulerAngles

## Installation

To install type in a shell
```shell
pip install BDQuaternions
```
Pip will install dependencies (*numpy* and *scipy*) for you.
Alternatively you can run in the root directory of BDQuaternions distribution
```shell
python setup.py install
```
Installation from source requires *Cython* package.
You will also need *setuptools* package for the installation.
## Usage

Please see the demo directory for the usage examples.

## License

BDQuaternions is free open source software licensed under Apache license version 2.0
